Class: StackOneHRIS::HrisCreateEmployeeRequestDto
- Inherits:
-
Object
- Object
- StackOneHRIS::HrisCreateEmployeeRequestDto
- Defined in:
- lib/stackone_hris_client/models/hris_create_employee_request_dto.rb
Instance Attribute Summary collapse
-
#avatar ⇒ Object
Returns the value of attribute avatar.
-
#avatar_url ⇒ Object
The employee avatar Url.
-
#birthday ⇒ Object
The employee birthday.
-
#company_name ⇒ Object
The employee company name.
-
#custom_fields ⇒ Object
The employee custom fields.
-
#date_of_birth ⇒ Object
The employee date_of_birth.
-
#department ⇒ Object
The employee department.
-
#display_name ⇒ Object
The employee display name.
-
#employment_contract_type ⇒ Object
Returns the value of attribute employment_contract_type.
-
#employment_status ⇒ Object
Returns the value of attribute employment_status.
-
#employment_type ⇒ Object
Returns the value of attribute employment_type.
-
#employments ⇒ Object
The employee employments.
-
#ethnicity ⇒ Object
Returns the value of attribute ethnicity.
-
#first_name ⇒ Object
The employee first name.
-
#gender ⇒ Object
Returns the value of attribute gender.
-
#hire_date ⇒ Object
The employee hire date.
-
#home_location ⇒ Object
Returns the value of attribute home_location.
-
#id ⇒ Object
The employee ID.
-
#job_title ⇒ Object
The employee job title.
-
#last_name ⇒ Object
The employee last name.
-
#manager_id ⇒ Object
The employee manager ID.
-
#marital_status ⇒ Object
Returns the value of attribute marital_status.
-
#name ⇒ Object
The employee name.
-
#personal_email ⇒ Object
The employee personal email.
-
#personal_phone_number ⇒ Object
The employee personal phone number.
-
#start_date ⇒ Object
The employee start date.
-
#tenure ⇒ Object
The employee tenure.
-
#termination_date ⇒ Object
The employee termination date.
-
#work_anniversary ⇒ Object
The employee work anniversary.
-
#work_email ⇒ Object
The employee work email.
-
#work_location ⇒ Object
Returns the value of attribute work_location.
-
#work_phone_number ⇒ Object
The employee work phone number.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HrisCreateEmployeeRequestDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ HrisCreateEmployeeRequestDto
Initializes the object
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 194 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `StackOneHRIS::HrisCreateEmployeeRequestDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `StackOneHRIS::HrisCreateEmployeeRequestDto`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'display_name') self.display_name = attributes[:'display_name'] end if attributes.key?(:'avatar_url') self.avatar_url = attributes[:'avatar_url'] end if attributes.key?(:'personal_email') self.personal_email = attributes[:'personal_email'] end if attributes.key?(:'personal_phone_number') self.personal_phone_number = attributes[:'personal_phone_number'] end if attributes.key?(:'work_email') self.work_email = attributes[:'work_email'] end if attributes.key?(:'work_phone_number') self.work_phone_number = attributes[:'work_phone_number'] end if attributes.key?(:'job_title') self.job_title = attributes[:'job_title'] end if attributes.key?(:'department') self.department = attributes[:'department'] end if attributes.key?(:'manager_id') self.manager_id = attributes[:'manager_id'] end if attributes.key?(:'gender') self.gender = attributes[:'gender'] end if attributes.key?(:'ethnicity') self.ethnicity = attributes[:'ethnicity'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'birthday') self.birthday = attributes[:'birthday'] end if attributes.key?(:'marital_status') self.marital_status = attributes[:'marital_status'] end if attributes.key?(:'avatar') self.avatar = attributes[:'avatar'] end if attributes.key?(:'hire_date') self.hire_date = attributes[:'hire_date'] end if attributes.key?(:'start_date') self.start_date = attributes[:'start_date'] end if attributes.key?(:'tenure') self.tenure = attributes[:'tenure'] end if attributes.key?(:'work_anniversary') self.work_anniversary = attributes[:'work_anniversary'] end if attributes.key?(:'employment_type') self.employment_type = attributes[:'employment_type'] end if attributes.key?(:'employment_contract_type') self.employment_contract_type = attributes[:'employment_contract_type'] end if attributes.key?(:'employment_status') self.employment_status = attributes[:'employment_status'] end if attributes.key?(:'termination_date') self.termination_date = attributes[:'termination_date'] end if attributes.key?(:'home_location') self.home_location = attributes[:'home_location'] end if attributes.key?(:'work_location') self.work_location = attributes[:'work_location'] end if attributes.key?(:'company_name') self.company_name = attributes[:'company_name'] end if attributes.key?(:'employments') if (value = attributes[:'employments']).is_a?(Array) self.employments = value end end if attributes.key?(:'custom_fields') if (value = attributes[:'custom_fields']).is_a?(Array) self.custom_fields = value end end end |
Instance Attribute Details
#avatar ⇒ Object
Returns the value of attribute avatar.
69 70 71 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 69 def avatar @avatar end |
#avatar_url ⇒ Object
The employee avatar Url
34 35 36 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 34 def avatar_url @avatar_url end |
#birthday ⇒ Object
The employee birthday
65 66 67 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 65 def birthday @birthday end |
#company_name ⇒ Object
The employee company name
97 98 99 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 97 def company_name @company_name end |
#custom_fields ⇒ Object
The employee custom fields
103 104 105 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 103 def custom_fields @custom_fields end |
#date_of_birth ⇒ Object
The employee date_of_birth
62 63 64 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 62 def date_of_birth @date_of_birth end |
#department ⇒ Object
The employee department
52 53 54 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 52 def department @department end |
#display_name ⇒ Object
The employee display name
31 32 33 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 31 def display_name @display_name end |
#employment_contract_type ⇒ Object
Returns the value of attribute employment_contract_type.
85 86 87 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 85 def employment_contract_type @employment_contract_type end |
#employment_status ⇒ Object
Returns the value of attribute employment_status.
87 88 89 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 87 def employment_status @employment_status end |
#employment_type ⇒ Object
Returns the value of attribute employment_type.
83 84 85 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 83 def employment_type @employment_type end |
#employments ⇒ Object
The employee employments
100 101 102 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 100 def employments @employments end |
#ethnicity ⇒ Object
Returns the value of attribute ethnicity.
59 60 61 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 59 def ethnicity @ethnicity end |
#first_name ⇒ Object
The employee first name
22 23 24 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 22 def first_name @first_name end |
#gender ⇒ Object
Returns the value of attribute gender.
57 58 59 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 57 def gender @gender end |
#hire_date ⇒ Object
The employee hire date
72 73 74 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 72 def hire_date @hire_date end |
#home_location ⇒ Object
Returns the value of attribute home_location.
92 93 94 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 92 def home_location @home_location end |
#id ⇒ Object
The employee ID
19 20 21 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 19 def id @id end |
#job_title ⇒ Object
The employee job title
49 50 51 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 49 def job_title @job_title end |
#last_name ⇒ Object
The employee last name
25 26 27 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 25 def last_name @last_name end |
#manager_id ⇒ Object
The employee manager ID
55 56 57 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 55 def manager_id @manager_id end |
#marital_status ⇒ Object
Returns the value of attribute marital_status.
67 68 69 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 67 def marital_status @marital_status end |
#name ⇒ Object
The employee name
28 29 30 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 28 def name @name end |
#personal_email ⇒ Object
The employee personal email
37 38 39 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 37 def personal_email @personal_email end |
#personal_phone_number ⇒ Object
The employee personal phone number
40 41 42 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 40 def personal_phone_number @personal_phone_number end |
#start_date ⇒ Object
The employee start date
75 76 77 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 75 def start_date @start_date end |
#tenure ⇒ Object
The employee tenure
78 79 80 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 78 def tenure @tenure end |
#termination_date ⇒ Object
The employee termination date
90 91 92 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 90 def termination_date @termination_date end |
#work_anniversary ⇒ Object
The employee work anniversary
81 82 83 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 81 def work_anniversary @work_anniversary end |
#work_email ⇒ Object
The employee work email
43 44 45 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 43 def work_email @work_email end |
#work_location ⇒ Object
Returns the value of attribute work_location.
94 95 96 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 94 def work_location @work_location end |
#work_phone_number ⇒ Object
The employee work phone number
46 47 48 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 46 def work_phone_number @work_phone_number end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
144 145 146 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 144 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 106 def self.attribute_map { :'id' => :'id', :'first_name' => :'first_name', :'last_name' => :'last_name', :'name' => :'name', :'display_name' => :'display_name', :'avatar_url' => :'avatar_url', :'personal_email' => :'personal_email', :'personal_phone_number' => :'personal_phone_number', :'work_email' => :'work_email', :'work_phone_number' => :'work_phone_number', :'job_title' => :'job_title', :'department' => :'department', :'manager_id' => :'manager_id', :'gender' => :'gender', :'ethnicity' => :'ethnicity', :'date_of_birth' => :'date_of_birth', :'birthday' => :'birthday', :'marital_status' => :'marital_status', :'avatar' => :'avatar', :'hire_date' => :'hire_date', :'start_date' => :'start_date', :'tenure' => :'tenure', :'work_anniversary' => :'work_anniversary', :'employment_type' => :'employment_type', :'employment_contract_type' => :'employment_contract_type', :'employment_status' => :'employment_status', :'termination_date' => :'termination_date', :'home_location' => :'home_location', :'work_location' => :'work_location', :'company_name' => :'company_name', :'employments' => :'employments', :'custom_fields' => :'custom_fields' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
407 408 409 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 407 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
187 188 189 190 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 187 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 149 def self.openapi_types { :'id' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'name' => :'String', :'display_name' => :'String', :'avatar_url' => :'String', :'personal_email' => :'String', :'personal_phone_number' => :'String', :'work_email' => :'String', :'work_phone_number' => :'String', :'job_title' => :'String', :'department' => :'String', :'manager_id' => :'String', :'gender' => :'EmployeeApiModelGender', :'ethnicity' => :'EmployeeApiModelEthnicity', :'date_of_birth' => :'Time', :'birthday' => :'Time', :'marital_status' => :'EmployeeApiModelMaritalStatus', :'avatar' => :'EmployeeApiModelAvatar', :'hire_date' => :'Time', :'start_date' => :'Time', :'tenure' => :'String', :'work_anniversary' => :'Time', :'employment_type' => :'EmployeeApiModelEmploymentType', :'employment_contract_type' => :'EmploymentEmploymentContractType', :'employment_status' => :'EmployeeApiModelEmploymentStatus', :'termination_date' => :'Time', :'home_location' => :'EmployeeApiModelHomeLocation', :'work_location' => :'EmployeeApiModelWorkLocation', :'company_name' => :'String', :'employments' => :'Array<Employment>', :'custom_fields' => :'Array<EmployeeCustomFields>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 355 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && first_name == o.first_name && last_name == o.last_name && name == o.name && display_name == o.display_name && avatar_url == o.avatar_url && personal_email == o.personal_email && personal_phone_number == o.personal_phone_number && work_email == o.work_email && work_phone_number == o.work_phone_number && job_title == o.job_title && department == o.department && manager_id == o.manager_id && gender == o.gender && ethnicity == o.ethnicity && date_of_birth == o.date_of_birth && birthday == o.birthday && marital_status == o.marital_status && avatar == o.avatar && hire_date == o.hire_date && start_date == o.start_date && tenure == o.tenure && work_anniversary == o.work_anniversary && employment_type == o.employment_type && employment_contract_type == o.employment_contract_type && employment_status == o.employment_status && termination_date == o.termination_date && home_location == o.home_location && work_location == o.work_location && company_name == o.company_name && employments == o.employments && custom_fields == o.custom_fields end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 438 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = StackOneHRIS.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 509 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 414 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
394 395 396 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 394 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
400 401 402 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 400 def hash [id, first_name, last_name, name, display_name, avatar_url, personal_email, personal_phone_number, work_email, work_phone_number, job_title, department, manager_id, gender, ethnicity, date_of_birth, birthday, marital_status, avatar, hire_date, start_date, tenure, work_anniversary, employment_type, employment_contract_type, employment_status, termination_date, home_location, work_location, company_name, employments, custom_fields].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
342 343 344 345 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 342 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
485 486 487 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 485 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 491 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
479 480 481 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 479 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
349 350 351 |
# File 'lib/stackone_hris_client/models/hris_create_employee_request_dto.rb', line 349 def valid? true end |